summaryrefslogtreecommitdiffstats
path: root/vespajlib/src/main/java/com/yahoo/tensor/Tensor.java
diff options
context:
space:
mode:
Diffstat (limited to 'vespajlib/src/main/java/com/yahoo/tensor/Tensor.java')
-rw-r--r--vespajlib/src/main/java/com/yahoo/tensor/Tensor.java5
1 files changed, 4 insertions, 1 deletions
diff --git a/vespajlib/src/main/java/com/yahoo/tensor/Tensor.java b/vespajlib/src/main/java/com/yahoo/tensor/Tensor.java
index 06e7b010a7a..94b00e7e277 100644
--- a/vespajlib/src/main/java/com/yahoo/tensor/Tensor.java
+++ b/vespajlib/src/main/java/com/yahoo/tensor/Tensor.java
@@ -533,7 +533,7 @@ public interface Tensor {
return IndexedTensor.Builder.of(type, dimensionSizes);
}
/** Returns the type this is building */
TensorType type();
/** Return a cell builder */
@@ -578,6 +578,9 @@ public interface Tensor {
return this;
}
+ /** Returns the type of the tensor this cell is build for. */
+ public TensorType type() { return tensorBuilder.type(); }
+
public CellBuilder label(String dimension, long label) {
return label(dimension, String.valueOf(label));
}
@@ -533,7 +533,7 @@ public interface Tensor {
return IndexedTensor.Builder.of(type, dimensionSizes);
}
- /** Returns the type this is building */
+ /** Returns the type of the tensor this is building */
TensorType type();
/** Return a cell builder */